﻿// Copyright (c) 2009 Paul Kohler
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software 
// and associated documentation files (the "Software"), to deal in the Software without restriction, 
// including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, 
// and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do 
// so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in all copies or substantial 
// portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, 
// INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
// PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR 
// COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
// CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
using System;
using System.IO;
using NUnit.Framework;
using NUnit.Framework.SyntaxHelpers;

namespace FileSystemDatabase.Tests
{
	[TestFixture]
	public class Backup_tests
	{
		#region Setup/Teardown

		[SetUp]
		public void TestSetUp()
		{
			_db = new JsonDatabase(_path);

			string backupFilename = Path.Combine(_path, "backup.zip");
			if (File.Exists(backupFilename))
			{
				File.Delete(backupFilename);
			}
		}

		#endregion

		[TestFixtureSetUp]
		public void TestFixtureSetUp()
		{
			_path = Path.GetFullPath(Path.Combine(AppDomain.CurrentDomain.BaseDirectory, @"..\..\SampleData"));
		}

		private string _path;
		private JsonDatabase _db;

		[Test]
		public void Can_create_a_backup_of_all_files_as_one_ZIP()
		{
			string zipFilename = _db.CreateBackup("backup.zip");
			Assert.That(zipFilename, Text.EndsWith(@"\backup.zip"));
			Assert.IsTrue(File.Exists(zipFilename));
		}
	}
}