﻿// Copyright (c) 2009 Paul Kohler
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software 
// and associated documentation files (the "Software"), to deal in the Software without restriction, 
// including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, 
// and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do 
// so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in all copies or substantial 
// portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, 
// INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
// PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR 
// COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
// CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
using System;
using Newtonsoft.Json;

namespace FileSystemDatabase
{
	/// <summary>
	/// A file system database implementation using JSON.
	/// </summary>
	public class JsonDatabase : FileSystemDatabase
	{
		/// <summary>
		/// Initializes a new instance of the <see cref="JsonDatabase"/> class.
		/// </summary>
		/// <param name="basePath">The base path of the file system database.</param>
		public JsonDatabase(string basePath)
			: base(basePath)
		{
			FileExtension = "json";
		}

		/// <summary>
		/// Serializes the specified object as a JSON string for writing to disk.
		/// </summary>
		/// <param name="row">The row.</param>
		/// <returns>
		/// A JSON string representation of the object.
		/// </returns>
		protected override string Serialize(object row)
		{
			Formatting formatting = Formatting.None;
			if (WriteIndented)
			{
				formatting = Formatting.Indented;
			}
			return JsonConvert.SerializeObject(row, formatting);
		}

		/// <summary>
		/// Deserializes the JSON <paramref name="fileData"/> string into an object of type <paramref name="rowType"/>.
		/// </summary>
		/// <param name="rowType">Type of the row.</param>
		/// <param name="fileData">The object as a JSON string.</param>
		/// <returns>An instance of the object.</returns>
		protected override object Deserialize(Type rowType, string fileData)
		{
			return JsonConvert.DeserializeObject(fileData, rowType);
		}
	}
}